/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM e:/builds/tinderbox/XR-Trunk/WINNT_5.2_Depend/mozilla/xpinstall/public/nsPIXPIProxy.idl
 */

#ifndef __gen_nsPIXPIProxy_h__
#define __gen_nsPIXPIProxy_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsPIXPIProxy */
#define NS_PIXPIPROXY_IID_STR "6f9d2890-167d-11d5-8daf-000064657374"

#define NS_PIXPIPROXY_IID \
  {0x6f9d2890, 0x167d, 0x11d5, \
    { 0x8d, 0xaf, 0x00, 0x00, 0x64, 0x65, 0x73, 0x74 }}

/**
 * nsPIXPIProxy
 *
 * Used to handle miscellaneous things that XPInstall needs to perform
 * over on the main UI thread.
 */
class NS_NO_VTABLE nsPIXPIProxy : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_PIXPIPROXY_IID)

  /* void refreshPlugins (in boolean reloadPages); */
  NS_IMETHOD RefreshPlugins(PRBool reloadPages) = 0;

  /* void notifyRestartNeeded (); */
  NS_IMETHOD NotifyRestartNeeded(void) = 0;

  /**
    * Puts up an alert dialog with an OK button.
    *
    * @param title
    *        Text to appear in the title of the dialog.
    * @param text
    *        Text to appear in the body of the dialog.
    */
  /* void alert (in wstring title, in wstring text); */
  NS_IMETHOD Alert(const PRUnichar *title, const PRUnichar *text) = 0;

  /**
     * Puts up a dialog with up to 3 buttons and an optional, labeled checkbox.
     *
     * @param aDialogTitle
     *        Text to appear in the title of the dialog.
     * @param aText
     *        Text to appear in the body of the dialog.
     * @param aButtonFlags
     *        A combination of Button Flags.
     * @param aButton0Title
     *        Used when button 0 uses TITLE_IS_STRING
     * @param aButton1Title
     *        Used when button 1 uses TITLE_IS_STRING
     * @param aButton2Title
     *        Used when button 2 uses TITLE_IS_STRING
     * @param aCheckMsg
     *        Text to appear with the checkbox.  Null if no checkbox.
     * @param aCheckState    
     *        Contains the initial checked state of the checkbox when this method
     *        is called and the final checked state after this method returns.
     *
     * @return index of the button pressed.
     *
     * Buttons are numbered 0 - 2. The implementation can decide whether the
     * sequence goes from right to left or left to right.  Button 0 is the
     * default button unless one of the Button Default Flags is specified.
     *
     * The value for aButtonFlags is constructed using the constants defined by
     * nsIPromptService.
     *
     * @see nsIPromptService
     */
  /* PRInt32 confirmEx (in wstring aDialogTitle, in wstring aText, in unsigned long aButtonFlags, in wstring aButton0Title, in wstring aButton1Title, in wstring aButton2Title, in wstring aCheckMsg, inout boolean aCheckState); */
  NS_IMETHOD ConfirmEx(const PRUnichar *aDialogTitle, const PRUnichar *aText, PRUint32 aButtonFlags, const PRUnichar *aButton0Title, const PRUnichar *aButton1Title, const PRUnichar *aButton2Title, const PRUnichar *aCheckMsg, PRBool *aCheckState, PRInt32 *_retval) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsPIXPIProxy, NS_PIXPIPROXY_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSPIXPIPROXY \
  NS_IMETHOD RefreshPlugins(PRBool reloadPages); \
  NS_IMETHOD NotifyRestartNeeded(void); \
  NS_IMETHOD Alert(const PRUnichar *title, const PRUnichar *text); \
  NS_IMETHOD ConfirmEx(const PRUnichar *aDialogTitle, const PRUnichar *aText, PRUint32 aButtonFlags, const PRUnichar *aButton0Title, const PRUnichar *aButton1Title, const PRUnichar *aButton2Title, const PRUnichar *aCheckMsg, PRBool *aCheckState, PRInt32 *_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSPIXPIPROXY(_to) \
  NS_IMETHOD RefreshPlugins(PRBool reloadPages) { return _to RefreshPlugins(reloadPages); } \
  NS_IMETHOD NotifyRestartNeeded(void) { return _to NotifyRestartNeeded(); } \
  NS_IMETHOD Alert(const PRUnichar *title, const PRUnichar *text) { return _to Alert(title, text); } \
  NS_IMETHOD ConfirmEx(const PRUnichar *aDialogTitle, const PRUnichar *aText, PRUint32 aButtonFlags, const PRUnichar *aButton0Title, const PRUnichar *aButton1Title, const PRUnichar *aButton2Title, const PRUnichar *aCheckMsg, PRBool *aCheckState, PRInt32 *_retval) { return _to ConfirmEx(aDialogTitle, aText, aButtonFlags, aButton0Title, aButton1Title, aButton2Title, aCheckMsg, aCheckState, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSPIXPIPROXY(_to) \
  NS_IMETHOD RefreshPlugins(PRBool reloadPages) { return !_to ? NS_ERROR_NULL_POINTER : _to->RefreshPlugins(reloadPages); } \
  NS_IMETHOD NotifyRestartNeeded(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->NotifyRestartNeeded(); } \
  NS_IMETHOD Alert(const PRUnichar *title, const PRUnichar *text) { return !_to ? NS_ERROR_NULL_POINTER : _to->Alert(title, text); } \
  NS_IMETHOD ConfirmEx(const PRUnichar *aDialogTitle, const PRUnichar *aText, PRUint32 aButtonFlags, const PRUnichar *aButton0Title, const PRUnichar *aButton1Title, const PRUnichar *aButton2Title, const PRUnichar *aCheckMsg, PRBool *aCheckState, PRInt32 *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->ConfirmEx(aDialogTitle, aText, aButtonFlags, aButton0Title, aButton1Title, aButton2Title, aCheckMsg, aCheckState, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public nsPIXPIProxy
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSPIXPIPROXY

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, nsPIXPIProxy)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* void refreshPlugins (in boolean reloadPages); */
NS_IMETHODIMP _MYCLASS_::RefreshPlugins(PRBool reloadPages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void notifyRestartNeeded (); */
NS_IMETHODIMP _MYCLASS_::NotifyRestartNeeded()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void alert (in wstring title, in wstring text); */
NS_IMETHODIMP _MYCLASS_::Alert(const PRUnichar *title, const PRUnichar *text)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* PRInt32 confirmEx (in wstring aDialogTitle, in wstring aText, in unsigned long aButtonFlags, in wstring aButton0Title, in wstring aButton1Title, in wstring aButton2Title, in wstring aCheckMsg, inout boolean aCheckState); */
NS_IMETHODIMP _MYCLASS_::ConfirmEx(const PRUnichar *aDialogTitle, const PRUnichar *aText, PRUint32 aButtonFlags, const PRUnichar *aButton0Title, const PRUnichar *aButton1Title, const PRUnichar *aButton2Title, const PRUnichar *aCheckMsg, PRBool *aCheckState, PRInt32 *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsPIXPIProxy_h__ */
